@@ -1,32 +1,62 @@
 package Modern::Perl;
-
-=head1 NAME
-
-Modern::Perl - enable all of the features of Modern Perl with one command
-
-=head1 VERSION
-
-Version 1.03
-
-=cut
-
-our $VERSION = '1.03';
+{
+  $Modern::Perl::VERSION = '1.20120105';
+}
+# ABSTRACT: enable all of the features of Modern Perl with one import
 
 use 5.010_000;
 
 use strict;
 use warnings;
 
+use autodie ();
 use mro     ();
 use feature ();
 
-sub import {
+sub import
+{
+    my ($class, $date) = @_;
+    my $feature_tag    = validate_date( $date );
+
     warnings->import();
     strict->import();
-    feature->import( ':5.10' );
+    feature->import( $feature_tag );
     mro::set_mro( scalar caller(), 'c3' );
 }
 
+my %dates =
+(
+    2009 => ':5.10',
+    2010 => ':5.10',
+    2011 => ':5.12',
+    2012 => ':5.14',
+);
+
+sub validate_date
+{
+    my $date = shift;
+    return ':5.10' unless $date;
+
+    my $year = substr $date, 0, 4;
+    return $dates{$year} if exists $dates{$year};
+
+    die "Unknown date '$date' requested\n";
+}
+
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Modern::Perl - enable all of the features of Modern Perl with one import
+
+=head1 VERSION
+
+version 1.20120105
+
 =head1 SYNOPSIS
 
 Modern Perl programs use several modules to enable additional features of Perl
@@ -41,8 +71,33 @@ resolution order; see C<perldoc mro> for an explanation.  In the future, it
 will include additional CPAN modules which have proven useful and stable.
 
 See L<http://www.modernperlbooks.com/mt/2009/01/toward-a-modernperl.html> for
-more information, and L<http://www.modernperlbooks.com/> for further discussion
-of Modern Perl and its implications.
+more information, L<http://www.modernperlbooks.com/> for further discussion of
+Modern Perl and its implications, and
+L<http://onyxneon.com/books/modern_perl/index.html> for a freely-downloadable
+Modern Perl tutorial.
+
+=head2 Forward Compatibility
+
+For forward compatibility, I recommend you specify a I<year> as the single
+optional import tag. For example:
+
+    use Modern::Perl 2009;
+    use Modern::Perl 2010;
+
+... both enable 5.10 features, while:
+
+    use Modern::Perl 2011;
+
+... enables 5.12 features and:
+
+    use Modern::Perl 2012;
+
+... enables 5.14 features. Obviously you cannot use 5.14 features on earlier
+versions, and Perl will throw the appropriate exception if you try.
+
+In the future--probably the C<Modern::Perl> 2013 timeframe--this module may
+drop support for 5.10 and will complain (once per process) if you use a year
+too old.
 
 =head1 AUTHOR
 
@@ -90,17 +145,27 @@ L<http://search.cpan.org/dist/Modern-Perl/>
 
 Damian Conway (inspiration from L<Toolkit>), Florian Ragwitz
 (L<B::Hooks::Parser>, so I didn't have to write it myself), chocolateboy (for
-suggesting that I don't even need L<B::Hooks::Parser>, at least for now),
-Damien Learns Perl, David Moreno, and Evan Carroll for reporting bugs and
-requesting features.
+suggesting that I don't even need L<B::Hooks::Parser>), Damien Learns Perl,
+David Moreno, Evan Carroll, and Elliot Shank for reporting bugs and requesting
+features.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 chromatic, all rights reserved.
+Copyright 2009-2012 chromatic, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl 5.10 itself.
+under the same terms as Perl 5.14 itself.
+
+=head1 AUTHOR
+
+chromatic
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by chromatic@wgz.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of Modern::Perl
